@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 Klaralvdalens Datakonsult AB (KDAB).
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtGui module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 Klaralvdalens Datakonsult AB (KDAB).
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qshadergenerator_p.h"
 
@@ -534,7 +498,7 @@ QByteArray QShaderGenerator::createShaderCode(const QStringList &enabledLayers)
 
             qCDebug(ShaderGenerator)
                     << "Begin Substituting " << v->name << " = " << v->assignment.expression;
-            for (Variable *ref : qAsConst(v->assignment.referencedVariables)) {
+            for (Variable *ref : std::as_const(v->assignment.referencedVariables)) {
                 // Recursively substitute
                 Variable::substitute(ref);
 
@@ -647,17 +611,17 @@ QByteArray QShaderGenerator::createShaderCode(const QStringList &enabledLayers)
             variableReplacements.append(std::move(replacement));
         }
 
-        int begin = 0;
+        qsizetype begin = 0;
         while ((begin = line.indexOf('$', begin)) != -1) {
-            int end = begin + 1;
+            qsizetype end = begin + 1;
             char endChar = line.at(end);
-            const int size = line.size();
-            while (end < size && (std::isalnum(endChar) || endChar == '_')) {
+            const qsizetype size = line.size();
+            while (end < size && (std::isalnum(uchar(endChar)) || endChar == '_')) {
                 ++end;
                 endChar = line.at(end);
             }
 
-            const int placeholderLength = end - begin;
+            const qsizetype placeholderLength = end - begin;
 
             const QByteArray variableName = line.mid(begin, placeholderLength);
             const auto replacementIt =
@@ -668,7 +632,7 @@ QByteArray QShaderGenerator::createShaderCode(const QStringList &enabledLayers)
 
             if (replacementIt != variableReplacements.cend()) {
                 line.replace(begin, placeholderLength, replacementIt->variable);
-                begin += replacementIt->variable.length();
+                begin += replacementIt->variable.size();
             } else {
                 begin = end;
             }
@@ -787,7 +751,7 @@ QByteArray QShaderGenerator::createShaderCode(const QStringList &enabledLayers)
     }
 
     // Go throug all lines and insert content
-    for (const LineContent &lineContent : qAsConst(lines)) {
+    for (const LineContent &lineContent : std::as_const(lines)) {
         if (!lineContent.rawContent.isEmpty()) {
             code << lineContent.rawContent;
         }
